@@ -917,7 +917,7 @@ def _impl_create_ncmat_composer_internal( cifloader, *, uiso_temperature, skip_d
             if uiso is not None:
                 assert uiso>0.0
                 if uiso_temperature is None:
-                    _nc_common.warn(f'ignoring uiso info present in CIF input for "{composstr}" since uiso_temperature parameter value is not provided\n')
+                    _nc_common.warn(f'ignoring uiso info present in CIF input for "{composstr}" since uiso_temperature parameter value is not provided')
                 else:
                     ncmat.set_dyninfo_msd( lbl, msd=uiso, temperature=uiso_temperature )
             _aniso = a.get('aniso',None)
@@ -1239,7 +1239,27 @@ def _cod_get_cifdata( codid, quiet = False ):
         return c
     if not quiet:
         _nc_common.print(f"Querying the Crystallography Open Database for entry {codid}")
-    result = _nc_common.download_url( "https://www.crystallography.net/cod/%i.cif"%(codid) )
+
+    mirror_urls = [
+        "https://www.crystallography.net/cod/%i.cif",#canonical first
+        'https://qiserver.ugr.es/cod/%i.cif',
+        'http://cod.ibt.lt/cod/%i.cif',
+    ]
+
+    result = None
+    while result is None:
+        #Fail gently and try next mirror - except for the last attempt.
+        url = mirror_urls.pop(0)%codid
+        result = _nc_common.download_url( url,
+                                          timeout = 10.0,
+                                          quiet_network_fail = bool(mirror_urls) )
+        if result or not mirror_urls:
+            break
+        nextdescr = '/'.join(mirror_urls[0].split('/')[0:-1])+'/'
+        _nc_common.print(f'Retrival failed. Trying mirror at: {nextdescr}')
+
+    assert result is not None
+
     if len(_cod_cache)==10:
         _cod_cache.pop(0)
     _cod_cache.append( (codid, result ) )
